@@ -4,7 +4,7 @@ import time
 from datetime import datetime, timedelta
 from enum import Enum, auto
 from pathlib import Path
-from typing import List, Optional, Dict
+from typing import List, Optional, Dict, Any
 
 import tzlocal
 from apscheduler.events import EVENT_JOB_EXECUTED, EVENT_JOB_ERROR, \
@@ -64,8 +64,9 @@ class JobInfo(BaseModel):
     module: str  # name of the module, where to find the callback function
     args: Optional[List] = []  # args to pass to the function
     kwargs: Optional[Dict] = {}  # kwargs to pass to the function
-    pydantic_args: Optional[List[tuple[str, Dict]]] = None  # args tuple of [] will be first parsed by model.parse_obj
-    pydantic_kwargs: Optional[Dict[str, tuple[str, Dict]]] = None  # kwargs to pass to the function
+    pydantic_args: Optional[
+        List[tuple[str, Any]]] = None  # args tuple of [] will be first parsed by model.parse_obj
+    pydantic_kwargs: Optional[Dict[str, tuple[str, Any]]] = None  # kwargs to pass to the function
     trigger: Optional[AllowedTrigger] = AllowedTrigger.date  # the trigger object that controls the schedule of this job
     trigger_config: dict = dict()  # configuration of the triggers
     coalesce: bool = False  # whether to only run the job once when several run times are due
@@ -388,7 +389,7 @@ class ScheduleThread(threading.Thread):
         task = Task.get_task_from_id(task.id)
         if task.job_info.pydantic_args is not None:
             for pyd_arg in task.job_info.pydantic_args:
-                task.job_info.args += getattr(sys.modules[task.job_info.module], pyd_arg[0]).parse_obj(pyd_arg[1])
+                task.job_info.args.append(getattr(sys.modules[task.job_info.module], pyd_arg[0]).parse_obj(pyd_arg[1]))
         if task.job_info.pydantic_kwargs is not None:
             for key, pyd_kwarg in task.job_info.pydantic_kwargs.items():
                 task.job_info.kwargs[key] = getattr(sys.modules[task.job_info.module], pyd_kwarg[0]).parse_obj(
